@@ -64,6 +64,9 @@ def call_repeatedly(interval, func, *args):
 class RmcpMsg(object):
     RMCP_HEADER_FORMAT = '!BxBB'
     ASF_RMCP_V_1_0 = 6
+    version = None
+    seq_number = None
+    class_of_msg = None
 
     def __init__(self, class_of_msg=None):
         if class_of_msg is not None:
@@ -147,6 +150,23 @@ class AsfMsg(object):
             return ' '.join('%02x' % b for b in array('B', self.sdu))
         return ''
 
+    @staticmethod
+    def from_data(sdu):
+        asf = AsfMsg()
+        asf.unpack(sdu)
+
+        try:
+            cls = {
+                AsfMsg().ASF_TYPE_PRESENCE_PING: AsfPing,
+                AsfMsg().ASF_TYPE_PRESENCE_PONG: AsfPong,
+            }[asf.asf_type]
+        except KeyError:
+            raise DecodingError('Unsupported ASF type(0x%02x)' % asf.asf_type)
+
+        instance = cls()
+        instance.unpack(sdu)
+        return instance
+
 
 class AsfPing(AsfMsg):
     def __init__(self):
@@ -159,6 +179,9 @@ class AsfPing(AsfMsg):
         if self.data:
             raise DecodingError('Data length is not zero')
 
+    def __str__(self):
+        return 'ping: ' + super(AsfMsg, self).__str__()
+
 
 class AsfPong(AsfMsg):
     DATA_FORMAT = '!IIBB6x'
@@ -170,6 +193,14 @@ class AsfPong(AsfMsg):
         self.supported_entities = 0
         self.supported_interactions = 0
 
+    def pack(self):
+        pdu = struct.pack(self.DATA_FORMAT,
+                          self.oem_iana_enterprise_number,
+                          self.oem_defined,
+                          self.supported_entities,
+                          self.supported_interactions)
+        return pdu
+
     def unpack(self, sdu):
         AsfMsg.unpack(self, sdu)
         # header_len = struct.calcsize(self.ASF_HEADER_FORMAT)
@@ -340,7 +371,7 @@ class Rmcp(object):
         if self.seq_number != 255:
             self.seq_number = (self.seq_number + 1) % 254
 
-    def _receive(self):
+    def _receive_rmcp_msg(self):
         (pdu, _) = self._sock.recvfrom(4096)
         rmcp = RmcpMsg()
         sdu = rmcp.unpack(pdu)
@@ -357,7 +388,7 @@ class Rmcp(object):
         self._send_rmcp_msg(tx_data, RMCP_CLASS_IPMI)
 
     def _receive_ipmi_msg(self):
-        (_, class_of_msg, pdu) = self._receive()
+        (_, class_of_msg, pdu) = self._receive_rmcp_msg()
         if class_of_msg != RMCP_CLASS_IPMI:
             raise DecodingError('invalid class field in ASF message')
         msg = IpmiMsg()
@@ -371,7 +402,7 @@ class Rmcp(object):
         self._send_rmcp_msg(msg.pack(), RMCP_CLASS_ASF)
 
     def _receive_asf_msg(self, cls):
-        (_, class_of_msg, data) = self._receive()
+        (_, class_of_msg, data) = self._receive_rmcp_msg()
         log().debug('ASF RX: msg')
         if class_of_msg != RMCP_CLASS_ASF:
             raise DecodingError('invalid class field in ASF message')
@@ -514,7 +545,7 @@ class Rmcp(object):
         header.rq_seq = self.next_sequence_number
         header.rq_lun = 0
         header.rq_sa = self.slave_address
-        header.cmd_id = cmdid
+        header.cmdid = cmdid
 
         # Bridge message
         if target.routing:
