@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Copyright (c) 2014  Kontron Europe GmbH
 #
@@ -28,6 +28,8 @@ from collections import namedtuple
 
 import pyipmi
 import pyipmi.interfaces
+from pyipmi.utils import py3_array_tobytes
+
 
 Command = namedtuple('Command', 'name fn')
 CommandHelp = namedtuple('CommandHelp', 'name arguments help')
@@ -292,7 +294,7 @@ def cmd_raw(ipmi, args):
 
     netfn = int(args[0], 0)
     raw_bytes = array('B', [int(d, 0) for d in args[1:]])
-    rsp = ipmi.raw_command(lun, netfn, raw_bytes.tostring())
+    rsp = ipmi.raw_command(lun, netfn, py3_array_tobytes(raw_bytes))
     print(' '.join('%02x' % d for d in array('B', rsp)))
 
 
@@ -361,7 +363,7 @@ def cmd_picmg_get_portstate_all(ipmi, args):
                 (p, s) = ipmi.get_port_state(channel, interface)
                 print_link_state(p, s)
             except pyipmi.errors.CompletionCodeError as e:
-                if e.cc is 0xcc:
+                if e.cc == 0xcc:
                     continue
 
 
@@ -438,7 +440,7 @@ Options:
   -h               Show this help
   -v               Be verbose
   -V               Print version
-  -I <interface>   Set interface (available: rmcp, aardvark, ipmitool)
+  -I <interface>   Set interface (available: rmcp, aardvark, ipmitool, ipmbdev)
   -H <host>        Set RMCP host
   -U <user>        Set RMCP user
   -P <password>    Set RMCP password
@@ -453,6 +455,9 @@ Aardvark interface options:
 
 Ipmitool interface options:
   interface_type    Set the interface type to be used (lan, lanplus, serial)
+
+Ipmbdev interface options:
+  port=<path>       Specify path to Linux IPMB device (/dev/ipmb-0 by default)
 '''[1:])
         print('Commands:')
 
@@ -493,6 +498,9 @@ def parse_interface_options(interface_name, options):
                 interface_options['interface_type'] = value
             else:
                 print('Warning: unknown option %s' % name)
+        elif interface_name == 'ipmbdev':
+            if name == 'port':
+                interface_options['port'] = value
 
     return interface_options
 
