@@ -180,6 +180,7 @@ class SendMessageReq(Message):
                  Bitfield.Bit('authenticated', 1, 0),
                  Bitfield.Bit('encrypted', 1, 0),
                  Bitfield.Bit('tracking', 2, 0),),
+        RemainingBytes('data'),
     )
 
 
@@ -302,7 +303,7 @@ class GetSessionChallengeRsp(Message):
     __fields__ = (
         CompletionCode(),
         UnsignedInt('temporary_session_id', 4),
-        String('challenge_string', 16, 0),
+        String('challenge_string', 16, '\x00' * 16),
     )
 
 
