@@ -195,8 +195,12 @@ class SdrCommon(object):
             self.next_id = next_id
 
     def __str__(self):
-        s = '["%-16s"] [%s]' % \
+        if hasattr(self, 'devide_id_string'):
+            s = '["%-16s"] [%s]' % \
             (self.device_id_string, ' '.join(['%02x' % b for b in self.data]))
+        else:
+            s = '[%s]' % \
+            (' '.join(['%02x' % b for b in self.data]))
         return s
 
     def _common_header(self, data):
@@ -227,23 +231,20 @@ class SdrCommon(object):
     def from_data(data, next_id=None):
         sdr_type = data[3]
 
-        try:
-            cls = {
-                SDR_TYPE_FULL_SENSOR_RECORD:
-                    SdrFullSensorRecord,
-                SDR_TYPE_COMPACT_SENSOR_RECORD:
-                    SdrCompactSensorRecord,
-                SDR_TYPE_EVENT_ONLY_SENSOR_RECORD:
-                    SdrEventOnlySensorRecord,
-                SDR_TYPE_FRU_DEVICE_LOCATOR_RECORD:
-                    SdrFruDeviceLocator,
-                SDR_TYPE_MANAGEMENT_CONTROLLER_DEVICE_LOCATOR_RECORD:
-                    SdrManagementControllerDeviceLocator,
-                SDR_TYPE_OEM_SENSOR_RECORD:
-                    SdrOEMSensorRecord,
-            }[sdr_type]
-        except KeyError:
-            raise DecodingError('Unsupported SDR type(0x%02x)' % sdr_type)
+        cls = {
+            SDR_TYPE_FULL_SENSOR_RECORD:
+                SdrFullSensorRecord,
+            SDR_TYPE_COMPACT_SENSOR_RECORD:
+                SdrCompactSensorRecord,
+            SDR_TYPE_EVENT_ONLY_SENSOR_RECORD:
+                SdrEventOnlySensorRecord,
+            SDR_TYPE_FRU_DEVICE_LOCATOR_RECORD:
+                SdrFruDeviceLocator,
+            SDR_TYPE_MANAGEMENT_CONTROLLER_DEVICE_LOCATOR_RECORD:
+                SdrManagementControllerDeviceLocator,
+            SDR_TYPE_OEM_SENSOR_RECORD:
+                SdrOEMSensorRecord,
+        }.get(sdr_type, SdrUnknownSensorRecord)
 
         return cls(data, next_id)
 
@@ -259,8 +260,6 @@ class SdrFullSensorRecord(SdrCommon):
 
     def __init__(self, data=None, next_id=None):
         super(SdrFullSensorRecord, self).__init__(data, next_id)
-        if data:
-            self._from_data(data)
 
     def __str__(self):
         s = '["%-16s"] [%s:%s] [%s]' \
@@ -487,8 +486,6 @@ class SdrFullSensorRecord(SdrCommon):
 class SdrCompactSensorRecord(SdrCommon):
     def __init__(self, data=None, next_id=None):
         super(SdrCompactSensorRecord, self).__init__(data, next_id)
-        if data:
-            self._from_data(data)
 
     def __str__(self):
         s = '["%-16s"] [%s]' \
@@ -529,8 +526,6 @@ class SdrCompactSensorRecord(SdrCommon):
 class SdrEventOnlySensorRecord(SdrCommon):
     def __init__(self, data=None, next_id=None):
         super(SdrEventOnlySensorRecord, self).__init__(data, next_id)
-        if data:
-            self._from_data(data)
 
     def __str__(self):
         return 'Not supported yet.'
@@ -558,8 +553,6 @@ class SdrEventOnlySensorRecord(SdrCommon):
 class SdrFruDeviceLocator(SdrCommon):
     def __init__(self, data=None, next_id=None):
         super(SdrFruDeviceLocator, self).__init__(data, next_id)
-        if data:
-            self._from_data(data)
 
     def __str__(self):
         s = '["%-16s"] [%s]' \
@@ -588,8 +581,6 @@ class SdrManagementControllerDeviceLocator(SdrCommon):
     def __init__(self, data=None, next_id=None):
         super(SdrManagementControllerDeviceLocator, self).__init__(
                 data, next_id)
-        if data:
-            self._from_data(data)
 
     def __str__(self):
         s = '["%-16s"] [%s]' \
@@ -616,8 +607,6 @@ class SdrManagementControllerDeviceLocator(SdrCommon):
 class SdrOEMSensorRecord(SdrCommon):
     def __init__(self, data=None, next_id=None):
         super(SdrOEMSensorRecord, self).__init__(data, next_id)
-        if data:
-            self._from_data(data)
 
     def __str__(self):
         return 'Not supported yet.'
@@ -627,3 +616,12 @@ class SdrOEMSensorRecord(SdrCommon):
 
         # record key bytes
         self._common_record_key(buffer.pop_slice(3))
+
+
+# Any SDR type not known or not implemented
+class SdrUnknownSensorRecord(SdrCommon):
+    def __init__(self, data=None, next_id=None):
+        super(SdrUnknownSensorRecord, self).__init__(data, next_id)
+
+    def __str__(self):
+        return 'Not supported yet.'
