@@ -4,7 +4,7 @@
 from mock import MagicMock
 from nose.tools import eq_, raises
 
-from pyipmi.errors import IpmiTimeoutError
+from pyipmi.errors import IpmiTimeoutError, IpmiConnectionError
 from pyipmi.interfaces import Ipmitool
 from pyipmi import Session, Target
 from pyipmi.utils import py3_array_tobytes
@@ -177,3 +177,22 @@ class TestIpmitool:
         cc, rsp = self._interface._parse_output(test_str)
         eq_(cc, 0xcc)
         eq_(rsp, None)
+
+    @raises(IpmiConnectionError)
+    def test_parse_output_connection_error_rmcp_plus(self):
+        test_str = b'Error: Unable to establish IPMI v2 / RMCP+ session\n'
+        cc, rsp = self._interface._parse_output(test_str)
+        eq_(cc, 0xcc)
+        eq_(rsp, None)
+
+    @raises(IpmiConnectionError)
+    def test_parse_output_connection_error(self):
+        test_str = b'Error: Unable to establish LAN session'
+        cc, rsp = self._interface._parse_output(test_str)
+        eq_(rsp, None)
+
+    @raises(IpmiConnectionError)
+    def test_parse_output_connection_error_rmcp(self):
+        test_str = b'Error: Unable to establish IPMI v1.5 / RMCP session'
+        cc, rsp = self._interface._parse_output(test_str)
+        eq_(rsp, None)
